@@ -1,8 +1,6 @@
-extern crate marine_rs_sdk;
-extern crate marine_sqlite_connector;
-
 use marine_rs_sdk::marine;
 use marine_sqlite_connector::State;
+use marine_sqlite_connector::Value;
 
 pub fn main() {}
 
@@ -10,31 +8,6 @@ pub fn main() {}
 pub fn test1() {
     let connection = marine_sqlite_connector::open(":memory:").unwrap();
 
-    connection
-        .execute(
-            "
-            CREATE TABLE users (name TEXT, age INTEGER);
-            INSERT INTO users VALUES ('Alice', 42);
-            INSERT INTO users VALUES ('Bob', 69);
-        ",
-        )
-        .unwrap();
-
-    connection
-        .iterate("SELECT * FROM users WHERE age > 50", |pairs| {
-            for &(column, value) in pairs.iter() {
-                println!("{} = {}", column, value.unwrap());
-            }
-            true
-        })
-        .unwrap();
-}
-
-#[marine]
-pub fn test2() {
-    let connection = marine_sqlite_connector::open(":memory:").unwrap();
-
-    println!("connection id = {}\n", connection.as_raw());
     connection
         .execute(
             "
@@ -51,15 +24,13 @@ pub fn test2() {
 
     statement.bind(1, 50).unwrap();
 
-    while let State::Row = statement.next().unwrap() {
-        println!("name = {}", statement.read::<String>(0).unwrap());
-        println!("age = {}", statement.read::<i64>(1).unwrap());
-    }
+    assert_eq!(statement.next().unwrap(), State::Row);
+    assert_eq!(statement.read::<String>(0).unwrap(), "Bob");
+    assert_eq!(statement.read::<i64>(1).unwrap(), 69);
 }
-#[marine]
-pub fn test3() {
-    use marine_sqlite_connector::Value;
 
+#[marine]
+pub fn test2() {
     let connection = marine_sqlite_connector::open(":memory:").unwrap();
 
     connection
@@ -80,7 +51,63 @@ pub fn test3() {
     cursor.bind(&[Value::Integer(50)]).unwrap();
 
     while let Some(row) = cursor.next().unwrap() {
-        println!("name = {}", row[0].as_string().unwrap());
-        println!("age = {}", row[1].as_integer().unwrap());
+        assert_eq!(row[0].as_string().unwrap(), "Bob");
+        assert_eq!(row[1].as_integer().unwrap(), 69);
+    }
+}
+
+#[marine]
+pub fn test3() {
+    let connection = marine_sqlite_connector::open(":memory:").unwrap();
+
+    connection
+        .execute(
+            "
+            CREATE TABLE test (number INTEGER, blob BLOB NOT NULL);
+        ",
+        )
+        .unwrap();
+
+    let mut cursor = connection
+        .prepare("INSERT OR REPLACE INTO test VALUES (?, ?)")
+        .unwrap();
+
+    cursor.bind(1, &Value::Integer(50)).unwrap();
+    cursor.bind(2, &Value::Binary(vec![1, 2, 3])).unwrap();
+
+    // check that blob is not null
+    assert!(cursor.next().is_ok());
+}
+
+#[marine]
+pub fn test4() {
+    let connection = marine_sqlite_connector::open(":memory:").unwrap();
+
+    connection
+        .execute(
+            "
+            CREATE TABLE test (number INTEGER, blob BLOB);
+        ",
+        )
+        .unwrap();
+
+    let mut cursor = connection
+        .prepare("INSERT OR REPLACE INTO test VALUES (?, ?)")
+        .unwrap();
+
+    cursor.bind(1, &Value::Integer(50)).unwrap();
+    cursor.bind(2, &Value::Binary(vec![1, 2, 3])).unwrap();
+
+    cursor.next().unwrap();
+
+    let mut cursor = connection
+        .prepare("SELECT blob FROM test WHERE number = ?")
+        .unwrap()
+        .cursor();
+
+    cursor.bind(&[Value::Integer(50)]).unwrap();
+
+    while let Some(row) = cursor.next().unwrap() {
+        assert_eq!(row[0].as_binary().unwrap().to_vec(), vec![1, 2, 3]);
     }
 }
